# Generated by Django 2.1.5 on 2019-04-04 21:12

from django.db import migrations, models
import django_tenants.postgresql_backend.base


class Migration(migrations.Migration):

    dependencies = [
        ('customers', '0002_auto_20171207_1616'),
    ]

    operations = [
        migrations.AlterField(
            model_name='client',
            name='schema_name',
            field=models.CharField(db_index=True, max_length=63, unique=True, validators=[django_tenants.postgresql_backend.base._check_schema_name]),
        ),
        migrations.AlterField(
            model_name='domain',
            name='is_primary',
            field=models.BooleanField(db_index=True, default=True),
        ),
    ]
